###########################################################
### Ch4 - Script 3 - MtFTb1_Medtr7g006630
###########################################################

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### Flowering time
###
###             NF_line      Wild-type (R108)
### NF3253      Q035         Q042
### NF0412      Q528         Q536
### NF5116      Q529, Q591   Q536, Q597
### NF14653     Q530, Q592
###########################################################
FTb1_groups <- FTdata %>% 
  filter(sowing_number %in% c("Q035", "Q042", "Q528", "Q536",
                              "Q529", "Q591", "Q597",
                              "Q530", "Q592"),
         !(sowing_number == "Q042" & conditions == 'VSD')) %>% 
  mutate(group = case_when(sowing_number %in% c("Q035", "Q042") ~ "NF3253",
                           sowing_number == "Q528" ~ "NF0412",
                           sowing_number %in% c("Q536", "Q529", "Q591", "Q597") ~ "NF5116",
                           sowing_number %in% c("Q530", "Q592") ~ "NF14653")) %>% 
  # Add R108 to group NF0412
  bind_rows(filter(., sowing_number == "Q536") %>% 
              mutate(group = "NF0412")) %>%
  # Add R108 to group NF14653
  bind_rows(filter(., sowing_number %in% c("Q536", "Q597")) %>% 
              select(-group) %>% 
              distinct() %>% 
              mutate(group = "NF14653")) %>% 
  mutate(group = factor(group, levels = c("NF0412", "NF3253",
                                          "NF5116", "NF14653")),
         mutant = if_else(mutant == "Wild-type", "Wild-type (R108)", mutant))

FTb1_flowering <- FTb1_groups %>%   
  ggplot(aes(days_to_flower, node_num, colour = fct_rev(mutant))) +
  geom_jitter(size = 2, alpha = 0.6) +
  facet_wrap( ~ group, nrow = 2) +
  scale_colour_manual(values = g_colours[c(10, 8)]) +
  stat_ellipse(size = 1,
               alpha = 0.6) +
  scale_x_continuous(expand = c(0, 0), limits = c(0, 40)) +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 15)) +
  labs(x = "Days to flower", y = "Nodes at flowering") +
  theme(legend.position=c(.15, .95),
        legend.text = element_text(size = 16),
        strip.text = element_text(hjust = -0.001),
        panel.spacing = unit(1.5, "lines"),
        axis.title.x = element_text(vjust = -2))

ggarrange(FTb1_flowering, NULL, 
          ncol = 2, labels = c("A", "B"),
          widths = c(1.5, 1))

ggsave("Ch4_FTb1_flowering.png", width = 393, height = 212, units = "mm")
# ggsave("Ch4_FTb1_flowering.pdf", width = 168, height = 143, units = 'mm')
